function love.load()
  x = love.graphics.getWidth() / 2
  y = love.graphics.getHeight() / 2
  radius = 50
  pointLen = 20
  points = 8
  moveAngle = 0
  snapDegrees = 10
  love.mouse.setVisible(false)
end

function love.update(dt)
  moveAngle = (moveAngle + math.pi * dt) % (math.pi * 2)
end

function love.draw()
  local angle = 0
  love.graphics.setLineWidth(5)
  
  -- static lines
  for i = 1, points do
    love.graphics.setColor(150, i == 1 and 0 or 150, 150)
    drawLine(angle, i == 1 and pointLen * 2 or pointLen)
    angle = angle + (math.pi * 2 / points)
  end
  
  -- moving line
  love.graphics.setColor(150, 0, 0)
  drawLine(moveAngle, pointLen)
  
  -- the circle
  love.graphics.setColor(150, 150, 150)
  love.graphics.circle("line", x, y, radius)
  
  -- get mouse angle
  local mx, my = love.mouse.getPosition()
  local angle = math.atan2(my - y, mx - x)
  if angle < 0 then angle = angle + math.pi * 2 end
  
  -- angle snapping
  if love.keyboard.isDown("lshift") then
    local dist = math.sqrt((mx - x) ^ 2 + (my - y) ^ 2)
    angle = math.rad(math.floor(math.deg(angle) / snapDegrees + .5) * snapDegrees) -- there's probably a much better way of doing this, but whatever
    mx = x + math.cos(angle) * dist
    my = y + math.sin(angle) * dist
  end
  
  -- make sure angle is below 360 degrees
  angle = angle % (math.pi * 2)
  
  -- draw line to mouse along with angle information
  love.graphics.setColor(255, 255, 255)
  love.graphics.setLineWidth(1)
  love.graphics.line(x, y, mx, my)
  love.graphics.print(("%.2f\n%.2f"):format(math.deg(angle), angle), mx, my)
  
  -- help information
  love.graphics.print("Purple line is 0 degrees/radians\nRed line shows the direction angles move in (clockwise)\nHold shift to snap mouse to increments of 10 degrees", 5, 5)
end

function drawLine(angle, length)
  local cos = math.cos(angle)
  local sin = math.sin(angle)
  love.graphics.line(x + cos * radius, y + sin * radius, x + cos * (radius + length), y + sin * (radius + length))
end
